@@ -1,29 +1,9 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2006-09-15
- * @brief  Iptc manipulation methods
- *
- * @author Copyright (C) 2006-2015 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2012 by Marcel Wiesweg
- *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2006-2015 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2006-2012 Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Local includes
 
@@ -38,7 +18,12 @@ bool KExiv2::canWriteIptc(const QString& filePath)
 {
     try
     {
-        Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const char*)
+#if EXIV2_TEST_VERSION(0,28,0)
+        Exiv2::Image::UniquePtr image = 
+#else
+        Exiv2::Image::AutoPtr image = 
+#endif
+                                      Exiv2::ImageFactory::open((const char*)
                                       (QFile::encodeName(filePath).constData()));
 
         Exiv2::AccessMode mode = image->checkMode(Exiv2::mdIptc);
@@ -48,7 +33,12 @@ bool KExiv2::canWriteIptc(const QString& filePath)
     {
         std::string s(e.what());
         qCCritical(LIBKEXIV2_LOG) << "Cannot check Iptc access mode using Exiv2 (Error #"
-                                  << e.code() << ": " << s.c_str() << ")";
+#if EXIV2_TEST_VERSION(0,28,0)
+                                  << Exiv2::Error(e.code()).what()
+#else
+                                  << e.code() << ": " << s.c_str()
+#endif
+                                  << ")";
     }
     catch(...)
     {
@@ -100,7 +90,11 @@ QByteArray KExiv2::getIptc(bool addIrbHeader) const
                 c2 = Exiv2::IptcParser::encode(d->iptcMetadata());
             }
 
+#if EXIV2_TEST_VERSION(0,28,0)
+            QByteArray data((const char*)c2.c_data(), c2.size());
+#else
             QByteArray data((const char*)c2.pData_, c2.size_);
+#endif
             return data;
 
         }
@@ -530,7 +524,11 @@ bool KExiv2::setIptcTagsStringList(const char* iptcTagName, int maxSize,
             QString key = *it;
             key.truncate(maxSize);
 
+#if EXIV2_TEST_VERSION(0,28,0)
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.toUtf8().constData());
             iptcData.add(iptcTag, val.get());
         }
@@ -631,7 +629,11 @@ bool KExiv2::setIptcKeywords(const QStringList& oldKeywords, const QStringList&
             QString key = *it;
             key.truncate(64);
 
+#if EXIV2_TEST_VERSION(0,28,0)
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.toUtf8().constData());
             iptcData.add(iptcTag, val.get());
         }
@@ -725,7 +727,11 @@ bool KExiv2::setIptcSubjects(const QStringList& oldSubjects, const QStringList&
             QString key = *it;
             key.truncate(236);
 
+#if EXIV2_TEST_VERSION(0,28,0)
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.toUtf8().constData());
             iptcData.add(iptcTag, val.get());
         }
@@ -820,7 +826,11 @@ bool KExiv2::setIptcSubCategories(const QStringList& oldSubCategories, const QSt
             QString key = *it;
             key.truncate(32);
 
+#if EXIV2_TEST_VERSION(0,28,0)
+            Exiv2::Value::UniquePtr val = Exiv2::Value::create(Exiv2::string);
+#else
             Exiv2::Value::AutoPtr val = Exiv2::Value::create(Exiv2::string);
+#endif
             val->read(key.toUtf8().constData());
             iptcData.add(iptcTag, val.get());
         }
